@@ -24,7 +24,7 @@ import commands
 import threading
 import ctypes
 from apt.progress.base import InstallProgress
-
+import time
 import historyclean
 import cookiesclean
 import searchsame
@@ -60,7 +60,7 @@ class OneKeyClean():
         flag_dic = {'history': False, 'cookies': False, 'cache': False}
         for mode in mode_list:
             flag_dic['%s' % mode] = True
-
+        time.sleep(1)
         if flag_dic['history']:
             historysize = 0
             objhg = historyclean.HistoryClean(homedir)
@@ -82,6 +82,7 @@ class OneKeyClean():
                         historysize += onec[2]
             total_dic['history'] = str(historysize)
             sesdaemon.total_data_transmit('h', total_dic['history'])
+        time.sleep(1)
         if flag_dic['cookies']:
             cookiessize = 0
             objcg = cookiesclean.CookiesClean(homedir)
@@ -103,6 +104,7 @@ class OneKeyClean():
                     cookiessize += onecc[1]
             total_dic['cookies'] = str(cookiessize)
             sesdaemon.total_data_transmit('k', total_dic['cookies'])
+        time.sleep(1)
         if flag_dic['cache']:
             cachesize = 0
             objcache = cacheclean.CacheClean()
@@ -130,6 +132,7 @@ class OneKeyClean():
         for mode in mode_list:
             flag_dic['%s' % mode] = True
         #if flag_dic['cache']:
+        time.sleep(1)
         if mode_list[0] in '1':
             try:
                 objclean = FunctionOfClean()
@@ -152,6 +155,7 @@ class OneKeyClean():
             else:
                 sysdaemon.clean_complete_onekey('c')
         #if flag_dic['history']:
+        time.sleep(1)
         if mode_list[1] in '1':
             try:
                 sysdaemon.status_for_quick_clean('firefoxhistory', 'start')
@@ -172,6 +176,7 @@ class OneKeyClean():
                 sysdaemon.clean_complete_onekey('h')
                 
         #if flag_dic['cookies']:
+        time.sleep(1)
         if mode_list[2] in '1':
             try:
                 objcc = cookiesclean.CookiesClean(homedir)
@@ -799,24 +804,29 @@ def interface_get_subpage_session(session, mode_dic):
                     
         
         if 'chromium' in cookies:
-            if cache['chromium-browser'].is_installed:
-                chcpath = "%s/.config/chromium/Default/Cookies" % homedir
-                if os.path.exists(chcpath):
-                    chcpam = [chcpath, 'cookies', 'host_key']
-                    chromium_cookies_list = cookies_obj.scan_cookies_records(chcpam[0], chcpam[1], chcpam[2])
-                    for value in chromium_cookies_list:
+            try:
+                pkg = cache['chromium-browser']
+            except KeyError:
+                pass
+            else:
+                if pkg.is_installed:
+                    chcpath = "%s/.config/chromium/Default/Cookies" % homedir
+                    if os.path.exists(chcpath):
+                        chcpam = [chcpath, 'cookies', 'host_key']
+                        chromium_cookies_list = cookies_obj.scan_cookies_records(chcpam[0], chcpam[1], chcpam[2])
+                        for value in chromium_cookies_list:
+                            info = []
+                            info.append('Belong:Cookies.chromium')
+                            info.append('Content:%s' % value[0])
+                            info.append('Count:%s' % str(value[-1]))
+                            session.subpage_data_signal(info)
+                    else:
                         info = []
                         info.append('Belong:Cookies.chromium')
-                        info.append('Content:%s' % value[0])
-                        info.append('Count:%s' % str(value[-1]))
+                        info.append('')
                         session.subpage_data_signal(info)
                 else:
-                    info = []
-                    info.append('Belong:Cookies.chromium')
-                    info.append('')
-                    session.subpage_data_signal(info)
-            else:
-                session.subpage_error_signal('Uninstalled:Chromium')
+                    session.subpage_error_signal('Uninstalled:Chromium')
         session.subpage_status_signal('Complete:Cookies')
 
 
@@ -852,25 +862,49 @@ def interface_get_subpage_session(session, mode_dic):
 
         if 'chromium' in history:
             chhpath = "%s/.config/chromium/Default/History" % homedir
-            if cache['chromium-browser'].is_installed:
-                run = common.process_pid("chromium-browser")
-                if not run:
-                    chromium_history_list = brohistory_obj.scan_chromium_history_records(chhpath)
-                    #for single in chromium_history_list:
-                    #    info = []
-                    #    info.append('Belong:History.chromium')
-                    #    info.append('Id:%s' % str(single[0]))
-                    #    info.append('Url:%s' % single[1])
-                    #    info.append('Count:%s' % str(single[2]))
-                    #    session.subpage_data_signal(info)
-                    info = []
-                    info.append('Belong:History.chromium')
-                    info.append('Count:%s' % str(len(chromium_history_list)))
-                    session.subpage_data_signal(info)
-                else:
-                    session.subpage_error_signal('Working:Chromium')
+            try:
+                pkg = cache['chromium-browser']
+            except KeyError:
+                pass
             else:
-                session.subpage_error_signal('Uninstalled:Chromium')
+                if pkg.is_installed:
+                    run = common.process_pid("chromium-browser")
+                    if not run:
+                        chromium_history_list = brohistory_obj.scan_chromium_history_records(chhpath)
+                        #for single in chromium_history_list:
+                        #    info = []
+                        #    info.append('Belong:History.chromium')
+                        #    info.append('Id:%s' % str(single[0]))
+                        #    info.append('Url:%s' % single[1])
+                        #    info.append('Count:%s' % str(single[2]))
+                        #    session.subpage_data_signal(info)
+                        info = []
+                        info.append('Belong:History.chromium')
+                        info.append('Count:%s' % str(len(chromium_history_list)))
+                        session.subpage_data_signal(info)
+                    else:
+                        session.subpage_error_signal('Working:Chromium')
+                else:
+                    session.subpage_error_signal('Uninstalled:Chromium')
+        if 'bash' in history:
+            path = os.path.join(homedir, ".bash_history")
+            size = 0
+            if os.path.exists(path):
+                size = common.confirm_filesize_unit(os.path.getsize(path))
+                info = []
+                info.append('Belong:History.bash')
+                info.append('Size:%s' % str(size))
+                info.append('Path:%s' % path)
+                session.subpage_data_signal(info)
+            else:
+                pass
+            
+
+        if 'X11' in history:
+            x11_list = [os.path.join(homedir, x) for x in os.listdir(homedir) if x.startswith(".xsession-errors")]
+            for value in x11_list:
+                info = append_cacheinfo_to_list('History.X11', value)
+                session.subpage_data_signal(info)
 
         if 'system' in history:
             syshistory_obj = systemhistory.SystemHistory()
@@ -920,8 +954,8 @@ def interface_get_subpage_session(session, mode_dic):
 
 
 def interface_remove_file_system(system, fp):
+        filepath = fp.encode("UTF-8")
         if os.path.exists(fp):
-            filepath = fp.encode("UTF-8")
             info = []
             if os.path.isdir(filepath):
                 info.append('Path:%s' % filepath)
@@ -966,7 +1000,7 @@ def interface_remove_chromium_history_system(system):
 def interface_remove_firefox_cookies_system(system, domain):
     homedir = return_homedir_sysdaemon()
     firefox_cookies_obj = cookiesclean.CookiesClean(homedir)
-    print(domain)
+    #print(domain)
 
     ffcpath = "%s/.mozilla/firefox/%s/cookies.sqlite" % (homedir, common.analytical_profiles_file(homedir))
     ffcpam = [ffcpath, 'moz_cookies', 'baseDomain', domain]
@@ -990,7 +1024,7 @@ def interface_remove_package_system(system, packagename):
             try:
                 pkg = cache[packagename]
             except KeyError:
-                system.subpage_error_signal('Non-existent:%s' % pkgname)
+                system.subpage_error_signal('Non-existent:%s' % packagename)
             if pkg.is_installed:
                 pkg.mark_delete()
             else:
