@@ -375,27 +375,62 @@ class DetailInfo:
                 uptime = str(minutes)
 
         platValue = platform.platform()
-        if not os.path.exists("/etc/ubuntukylin-release"):
-            if "Ubuntu" in platValue and "Kylin" not in platValue:
-                with open("/etc/lsb-release", "r") as fsys:
-                    for line in fsys:
-                        if line.startswith("DISTRIB_DESCRIPTION"):
-                            tmp = line
-                            break
-                # kobe: remove '"' and '\n'
-                front = tmp.split('=')[1].replace('"', '').replace('\n', '')
-                if front.startswith("UbuntuKylin") or front.startswith("Ubuntu Kylin"):
-                    platValue = platValue.replace('Ubuntu', 'Ubuntu Kylin')
+        if os.path.exists("/etc/ubuntukylin-release"):
+            with open("/etc/ubuntukylin-release", "r") as fsys:
+                for line in fsys:
+                    if line.startswith("DISTRIB_DESCRIPTION"):
+                        tmp = line
+                        break
+            # kobe: remove '"' and '\n'
+            front = tmp.split('=')[1].replace('"', '').replace('\n', '')
+            platValue = front
+#            if front.startswith("UbuntuKylin") or front.startswith("Ubuntu Kylin"):
+#                platValue = platValue.replace('Ubuntu', 'Ubuntu Kylin')
+        elif os.path.exists("/etc/os-release"):
+            with open("/etc/os-release", "r") as fsys:
+                for line in fsys:
+                    if line.startswith("NAME"):
+                        tmp = line
+                        break
+            # kobe: remove '"' and '\n'
+            front = tmp.split('=')[1].replace('"', '').replace('\n', '')
+            platValue = front
+#            if front.startswith("UbuntuKylin") or front.startswith("Ubuntu Kylin"):
+#                platValue = platValue.replace('Ubuntu', 'Ubuntu Kylin')
         else:
-            with open("/etc/ubuntukylin-release", "r") as fp:
+            with open("/etc/lsb-release", "r") as fp:
                 for line in fp:
-                    if line.startswith("DISTRIB_ID"):
+                    if line.startswith("DISTRIB_DESCRIPTION"):
                         tmp = line
                         break
             # kobe: remove '"' and '\n'
             id = tmp.split('=')[1].replace('"', '').replace('\n', '')
-            if "Ubuntu" in platValue:
-                platValue = platValue.replace('Ubuntu', id)
+            platValue = id
+#            if "Ubuntu" in platValue:
+#                platValue = platValue.replace('Ubuntu', id)
+
+
+#        if not os.path.exists("/etc/ubuntukylin-release"):
+#            if "Ubuntu" in platValue and "Kylin" not in platValue:
+#                with open("/etc/lsb-release", "r") as fsys:
+#                    for line in fsys:
+#                        if line.startswith("DISTRIB_DESCRIPTION"):
+#                            tmp = line
+#                            break
+#                # kobe: remove '"' and '\n'
+#                front = tmp.split('=')[1].replace('"', '').replace('\n', '')
+#                if front.startswith("UbuntuKylin") or front.startswith("Ubuntu Kylin"):
+#                    platValue = platValue.replace('Ubuntu', 'Ubuntu Kylin')
+#        else:
+#            with open("/etc/ubuntukylin-release", "r") as fp:
+#                for line in fp:
+#                    if line.startswith("DISTRIB_ID"):
+#                        tmp = line
+#                        break
+#            # kobe: remove '"' and '\n'
+#            id = tmp.split('=')[1].replace('"', '').replace('\n', '')
+#            if "Ubuntu" in platValue:
+#                platValue = platValue.replace('Ubuntu', id)
 
         Com['platform'] = platValue
 
@@ -757,7 +792,7 @@ class DetailInfo:
 
     def get_network(self):
         net = {}
-        NetProduct,NetVendor,NetBusinfo,NetLogicalname,NetSerial,NetIp,NetLink,NetCapacity = '','','','','','','',''
+        NetProduct,NetVendor,NetDrive,NetBusinfo,NetLogicalname,NetSerial,NetIp,NetLink,NetCapacity = '','','','','','','','',''
         n = os.popen('lspci -vvv')
         network = n.read()
         n.close()
@@ -816,17 +851,19 @@ class DetailInfo:
 
 
 
-
-        n = os.popen('mii-tool -v')
-        network = n.read()
-        n.close()
-        if network :
-            tmp = re.findall("basic status: (.*)",network)
-            if tmp:
-                NetLink = tmp[0]
-            tmp = re.findall('capabilities: (\d*)',network)
-            if tmp:
-                NetCapacity = tmp[0]
+        try:
+            n = os.popen('mii-tool -v')
+            network = n.read()
+            n.close()
+            if network :
+                tmp = re.findall("basic status: (.*)",network)
+                if tmp:
+                    NetLink = tmp[0]
+                tmp = re.findall('capabilities: (\d*)',network)
+                if tmp:
+                    NetCapacity = tmp[0]
+        except Exception, e:
+            print e
         WlanProduct,WlanVendor,WlanBusinfo,WlanLogicalname,WlanSerial,WlanIp,WlanDrive = '','','','','','',''
         n = os.popen('lspci -vvv')
         wlan = n.read()
