@@ -27,7 +27,12 @@ import re
 import subprocess
 import commands
 
-VERSION = "1.2.0"
+BOOL_TYPE = 1
+INT_TYPE = 2
+DOUBLE_TYPE = 3
+STRING_TYPE = 4
+
+VERSION = "2.0.3"
 str_agent = []
 LEN_AGENT = 10
 
@@ -142,6 +147,12 @@ def run_app(pkgname):
     cmd = get_run_command(pkgname)
     p = subprocess.Popen(cmd, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=False)
 
+def get_output(cmd):
+    '''status =0 : success'''
+    status, output = commands.getstatusoutput(cmd)
+    if status: raise
+    return output
+
 if __name__ == '__main__':
     ip = get_ip()
     print ip
