@@ -37,20 +37,57 @@ SessionDispatcher::SessionDispatcher(QObject *parent)
     QObject::connect(sessioniface, SIGNAL(subpage_status_signal(QString)), this, SLOT(handlerScanCleanerStatus(QString)));
     QObject::connect(sessioniface, SIGNAL(subpage_error_signal(QString)), this, SLOT(handlerScanCleanerError(QString)));
 
-    thread = new KThread(this);
+//    thread = new KThread(this);
+
+
+    //kobe
+    check_thread = new KThread(this);
+    scan_thread = new KThread(this);
+    onekey_scan_thread = new KThread(this);
+
     QObject::connect(sessioniface, SIGNAL(display_scan_process(QString)), this, SLOT(handler_scan_process(QString)));
     QObject::connect(sessioniface, SIGNAL(scan_complete(QString)), this, SLOT(handler_scan_complete(QString)));
     QObject::connect(sessioniface, SIGNAL(total_data_transmit(QString, QString)), this, SLOT(handler_total_data_transmit(QString,QString)));
     QObject::connect(sessioniface, SIGNAL(youkerid_whoami_signal(QString, QString)), this, SLOT(handlerYoukerID(QString, QString)));
     QObject::connect(sessioniface, SIGNAL(youkerid_logout_signal()), this, SLOT(handlerLogoutSuccess()));
     QObject::connect(sessioniface, SIGNAL(youkerid_login_fail_signal()), this, SLOT(handlerLoginFail()));
+
+
+    QObject::connect(sessioniface, SIGNAL(notify_boolean(QString, bool)), this, SLOT(handler_notify_boolean(QString, bool)));
+    QObject::connect(sessioniface, SIGNAL(notify_int(QString, int)), this, SLOT(handler_notify_int(QString, int)));
+    QObject::connect(sessioniface, SIGNAL(notify_double(QString, double)), this, SLOT(handler_notify_double(QString, double)));
+    QObject::connect(sessioniface, SIGNAL(notify_string(QString, QString)), this, SLOT(handler_notify_string(QString, QString)));
+
+    QObject::connect(sessioniface, SIGNAL(check_source_list_signal(bool)), this, SIGNAL(receive_source_list_signal(bool)));
 }
 
 SessionDispatcher::~SessionDispatcher() {
-    if(thread != NULL) {
-        delete thread;
-        thread = NULL;
+    check_thread->terminate();
+    check_thread->wait();
+    if(check_thread != NULL) {
+        delete check_thread;
+        check_thread = NULL;
     }
+    scan_thread->terminate();
+    scan_thread->wait();
+    if(scan_thread != NULL) {
+        delete scan_thread;
+        scan_thread = NULL;
+    }
+    onekey_scan_thread->terminate();
+    onekey_scan_thread->wait();
+    if(onekey_scan_thread != NULL) {
+        delete onekey_scan_thread;
+        onekey_scan_thread = NULL;
+    }
+
+
+//    thread->terminate();
+//    thread->wait();
+//    if(thread != NULL) {
+//        delete thread;
+//        thread = NULL;
+//    }
     this->exit_qt();
     if (sessioniface != NULL) {
         delete sessioniface;
@@ -63,12 +100,28 @@ void SessionDispatcher::exit_qt() {
     sessioniface->call("exit");
 }
 
-QString SessionDispatcher::checkNewVersion()
+QStringList SessionDispatcher::checkNewVersion()
 {
-    QDBusReply<QString> reply = sessioniface->call("currently_installed_version");
+    QDBusReply<QStringList> reply = sessioniface->call("currently_installed_version");
     return reply.value();
 }
 
+bool SessionDispatcher::start_check_source_useable_qt()
+{
+//    QDBusReply<bool> reply = sessioniface->call("start_check_source_useable");
+//    return reply.value();
+    if (check_thread->isRunning()) {
+        qDebug() << "check_thread is running......";
+    }
+    else {
+        QMap<QString, QVariant> data;
+        QStringList tmplist;
+        check_thread->initValues(data, tmplist, sessioniface, "start_check_source_useable");
+        check_thread->start();
+//        qDebug() << "check_thread is ready to run......";
+    }
+}
+
 void SessionDispatcher::runApp(QString pkgname)
 {
     sessioniface->call("run_selected_app", pkgname);
@@ -122,17 +175,24 @@ void SessionDispatcher::handlerScanCleanerError(QString status)
     emit this->tellCleanerDetailError(status);
 }
 
-bool SessionDispatcher::judge_camera_qt() {
-    QDBusReply<bool> reply = sessioniface->call("judge_camera");
-    return reply.value();
-}
+//bool SessionDispatcher::judge_camera_qt() {
+//    QDBusReply<bool> reply = sessioniface->call("judge_camera");
+//    return reply.value();
+//}
 
-void SessionDispatcher::call_camera_qt() {
-    QStringList tmp;
-    QMap<QString, QVariant> data;
-    thread->initValues(data, tmp, sessioniface, "call_camera");
-    thread->start();
-}
+//void SessionDispatcher::call_camera_qt() {
+//    sessioniface->call("call_camera");
+////    if (thread->isRunning()) {
+////        qDebug() << "camera_thread is running......";
+////    }
+////    else {
+////        qDebug() << "camera_thread is ready to run......";
+////        QStringList tmp;
+////        QMap<QString, QVariant> data;
+////        thread->initValues(data, tmp, sessioniface, "call_camera");
+////        thread->start();
+////    }
+//}
 
 bool SessionDispatcher::judge_power_is_exists_qt() {
     QDBusReply<bool> reply = sessioniface->call("judge_power_is_exists");
@@ -220,16 +280,42 @@ void SessionDispatcher::handler_total_data_transmit(QString flag, QString msg) {
 //}
 
 void SessionDispatcher::onekey_scan_function_qt(QStringList selectedList) {
-    QMap<QString, QVariant> data;
-    thread->initValues(data, selectedList, sessioniface, "onekey_scan_function");
-    thread->start();
+//    QMap<QString, QVariant> data;
+//    thread->initValues(data, selectedList, sessioniface, "onekey_scan_function");
+//    thread->start();
+
+    if (scan_thread->isRunning()) {
+        qDebug() << "onekey_scan_thread is running......";
+    }
+    else {
+//        qDebug() << "onekey_scan_thread is ready to run......";
+        QMap<QString, QVariant> data;
+        onekey_scan_thread->initValues(data, selectedList, sessioniface, "onekey_scan_function");
+        onekey_scan_thread->start();
+    }
 }
 
 void SessionDispatcher::scanSystemCleanerItems(QMap<QString, QVariant> data)
 {
-    QStringList tmp;
-    thread->initValues(data, tmp, sessioniface, "get_scan_result");
-    thread->start();
+//    QStringList tmp;
+//    thread->initValues(data, tmp, sessioniface, "get_scan_result");
+//    thread->start();
+    if (scan_thread->isRunning()) {
+        qDebug() << "scan_thread is running......";
+    }
+    else {
+//        if (scan_thread == NULL)
+//            qDebug() << "scan_thread is null, ready to run......";
+//        else
+//            qDebug() << "scan_thread is not null, ready to run......";
+        QStringList tmp;
+        scan_thread->initValues(data, tmp, sessioniface, "get_scan_result");
+        scan_thread->start();
+//        QElapsedTimer et;
+//        et.start();
+//        while(et.elapsed()<300)
+//            QCoreApplication::processEvents();
+    }
 }
 
 QString SessionDispatcher::getHomePath() {
@@ -274,6 +360,16 @@ bool SessionDispatcher::get_show_desktop_icons_qt() {
     return reply.value();
 }
 
+bool SessionDispatcher::set_show_computer_qt(bool flag) {
+    QDBusReply<bool> reply = sessioniface->call("set_show_computer", flag);
+    return reply.value();
+}
+
+bool SessionDispatcher::get_show_computer_qt() {
+    QDBusReply<bool> reply = sessioniface->call("get_show_computer");
+    return reply.value();
+}
+
 bool SessionDispatcher::set_show_homefolder_qt(bool flag) {
     QDBusReply<bool> reply = sessioniface->call("set_show_homefolder", flag);
     return reply.value();
@@ -283,6 +379,7 @@ bool SessionDispatcher::get_show_homefolder_qt() {
     QDBusReply<bool> reply = sessioniface->call("get_show_homefolder");
     return reply.value();
 }
+
 bool SessionDispatcher::set_show_network_qt(bool flag) {
     QDBusReply<bool> reply = sessioniface->call("set_show_network", flag);
     return reply.value();
@@ -292,6 +389,7 @@ bool SessionDispatcher::get_show_network_qt() {
     QDBusReply<bool> reply = sessioniface->call("get_show_network");
     return reply.value();
 }
+
 bool SessionDispatcher::set_show_trash_qt(bool flag) {
     QDBusReply<bool> reply = sessioniface->call("set_show_trash", flag);
     return reply.value();
@@ -301,6 +399,7 @@ bool SessionDispatcher::get_show_trash_qt() {
     QDBusReply<bool> reply = sessioniface->call("get_show_trash");
     return reply.value();
 }
+
 bool SessionDispatcher::set_show_devices_qt(bool flag) {
     QDBusReply<bool> reply = sessioniface->call("set_show_devices", flag);
     return reply.value();
@@ -404,6 +503,31 @@ bool SessionDispatcher::get_launcher_have_showdesktopicon_qt() {
     return reply.value();
 }
 
+//-----------------------------------------------mate----------------------------------------------
+bool SessionDispatcher::set_mate_panel_autohide_qt(QString positon, bool flag)
+{
+    QDBusReply<bool> reply = sessioniface->call("set_mate_panel_autohide", positon, flag);
+    return reply.value();
+}
+
+bool SessionDispatcher::get_mate_panel_autohide_qt(QString positon)
+{
+    QDBusReply<bool> reply = sessioniface->call("get_mate_panel_autohide", positon);
+    return reply.value();
+}
+
+bool SessionDispatcher::set_mate_panel_icon_size_qt(QString positon, int num)
+{
+    QDBusReply<bool> reply = sessioniface->call("set_mate_panel_icon_size", positon, num);
+    return reply.value();
+}
+
+int SessionDispatcher::get_mate_panel_icon_size_qt(QString positon)
+{
+    QDBusReply<bool> reply = sessioniface->call("get_mate_panel_icon_size", positon);
+    return reply.value();
+}
+
 //透明度
 double SessionDispatcher::get_launcher_transparency_qt() {
     QDBusReply<double> reply = sessioniface->call("get_launcher_transparency");
@@ -535,6 +659,48 @@ bool SessionDispatcher::set_show_power_percentage_qt(bool flag) {
     return reply.value();
 }
 
+//--------------------------mate--------------------
+bool SessionDispatcher::get_show_apps_qt() {
+    QDBusReply<bool> reply = sessioniface->call("get_show_apps");
+    return reply.value();
+}
+
+bool SessionDispatcher::set_show_apps_qt(bool flag) {
+    QDBusReply<bool> reply = sessioniface->call("set_show_apps", flag);
+    return reply.value();
+}
+
+bool SessionDispatcher::get_show_desktop_qt() {
+    QDBusReply<bool> reply = sessioniface->call("get_show_desktop");
+    return reply.value();
+}
+
+bool SessionDispatcher::set_show_desktop_qt(bool flag) {
+    QDBusReply<bool> reply = sessioniface->call("set_show_desktop", flag);
+    return reply.value();
+}
+
+bool SessionDispatcher::get_show_icon_qt() {
+    QDBusReply<bool> reply = sessioniface->call("get_show_icon");
+    return reply.value();
+}
+
+bool SessionDispatcher::set_show_icon_qt(bool flag) {
+    QDBusReply<bool> reply = sessioniface->call("set_show_icon", flag);
+    return reply.value();
+}
+
+bool SessionDispatcher::get_show_places_qt() {
+    QDBusReply<bool> reply = sessioniface->call("get_show_places");
+    return reply.value();
+}
+
+bool SessionDispatcher::set_show_places_qt(bool flag) {
+    QDBusReply<bool> reply = sessioniface->call("set_show_places", flag);
+    return reply.value();
+}
+
+
 /*-----------------------------theme of beauty-----------------------------*/
 QStringList SessionDispatcher::get_themes_qt() {
     QDBusReply<QStringList> reply = sessioniface->call("get_themes");
@@ -601,6 +767,18 @@ void SessionDispatcher::set_cursor_size_qt(int size) {
 //    sessioniface->call("set_window_theme", theme);
 //}
 
+QString SessionDispatcher::get_default_font_string_qt(QString schema, QString key)
+{
+    QDBusReply<QString> reply = sessioniface->call("get_default_font_string", schema, key);
+    return reply.value();
+}
+
+bool SessionDispatcher::set_default_font_string_qt(QString schema, QString key, QString type)
+{
+    QDBusReply<bool> reply = sessioniface->call("set_default_font", schema, key, type);
+    return reply.value();
+}
+
 QString SessionDispatcher::get_font_qt() {
     QDBusReply<QString> reply = sessioniface->call("get_font");
     return reply.value();
@@ -743,6 +921,11 @@ bool SessionDispatcher::get_touchpad_enable_qt() {
     return reply.value();
 }
 
+bool SessionDispatcher::set_touchscrolling_mode_disabled_qt() {
+    QDBusReply<bool> reply = sessioniface->call("set_touchscrolling_mode_disabled");
+    return reply.value();
+}
+
 bool SessionDispatcher::set_touchscrolling_mode_edge_qt() {
     QDBusReply<bool> reply = sessioniface->call("set_touchscrolling_mode_edge");
     return reply.value();
@@ -768,19 +951,31 @@ bool SessionDispatcher::get_touchscrolling_use_horizontal_qt() {
     return reply.value();
 }
 
+int SessionDispatcher::get_mate_touchscrolling_mode_qt()
+{
+    QDBusReply<int> reply = sessioniface->call("get_mate_touchscrolling_mode");
+    return reply.value();
+}
+
+bool SessionDispatcher::set_mate_touchscrolling_mode_qt(int value)
+{
+    QDBusReply<bool> reply = sessioniface->call("set_mate_touchscrolling_mode", value);
+    return reply.value();
+}
+
 /*-----------------------------window of beauty-----------------------------*/
-//void SessionDispatcher::set_window_button_align_left_qt() {
-//    sessioniface->call("set_window_button_align_left");
-//}
+void SessionDispatcher::set_window_button_align_left_qt() {
+    sessioniface->call("set_window_button_align_left");
+}
 
-//void SessionDispatcher::set_window_button_align_right_qt() {
-//    sessioniface->call("set_window_button_align_right");
-//}
+void SessionDispatcher::set_window_button_align_right_qt() {
+    sessioniface->call("set_window_button_align_right");
+}
 
-//QString SessionDispatcher::get_window_button_align_qt() {
-//    QDBusReply<QString> reply = sessioniface->call("get_window_button_align");
-//    return reply.value();
-//}
+QString SessionDispatcher::get_window_button_align_qt() {
+    QDBusReply<QString> reply = sessioniface->call("get_window_button_align");
+    return reply.value();
+}
 
 bool SessionDispatcher::set_menus_have_icons_qt(bool flag) {
     QDBusReply<bool> reply = sessioniface->call("set_menus_have_icons", flag);
@@ -806,8 +1001,8 @@ void SessionDispatcher::set_titlebar_wheel_qt(QString value) {
     sessioniface->call("set_titlebar_wheel", value);
 }
 
-QStringList SessionDispatcher::get_titlebar_double_qt() {
-    QDBusReply<QStringList> reply = sessioniface->call("get_titlebar_double");
+QStringList SessionDispatcher::get_titlebar_options_qt() {
+    QDBusReply<QStringList> reply = sessioniface->call("get_titlebar_options");
     return reply.value();
 }
 
@@ -820,10 +1015,10 @@ void SessionDispatcher::set_titlebar_double_qt(QString value) {
     sessioniface->call("set_titlebar_double", value);
 }
 
-QStringList SessionDispatcher::get_titlebar_middle_qt() {
-    QDBusReply<QStringList> reply = sessioniface->call("get_titlebar_middle");
-    return reply.value();
-}
+//QStringList SessionDispatcher::get_titlebar_middle_qt() {
+//    QDBusReply<QStringList> reply = sessioniface->call("get_titlebar_middle");
+//    return reply.value();
+//}
 
 QString SessionDispatcher::get_current_titlebar_middle_qt() {
     QDBusReply<QString> reply = sessioniface->call("get_current_titlebar_middle");
@@ -834,10 +1029,10 @@ void SessionDispatcher::set_titlebar_middle_qt(QString value) {
     sessioniface->call("set_titlebar_middle", value);
 }
 
-QStringList SessionDispatcher::get_titlebar_right_qt() {
-    QDBusReply<QStringList> reply = sessioniface->call("get_titlebar_right");
-    return reply.value();
-}
+//QStringList SessionDispatcher::get_titlebar_right_qt() {
+//    QDBusReply<QStringList> reply = sessioniface->call("get_titlebar_right");
+//    return reply.value();
+//}
 
 QString SessionDispatcher::get_current_titlebar_right_qt() {
     QDBusReply<QString> reply = sessioniface->call("get_current_titlebar_right");
@@ -948,10 +1143,10 @@ int SessionDispatcher::get_thumbnail_cache_size_qt() {
     return reply.value();
 }
 
-//QString SessionDispatcher::access_current_desktop_qt() {
-//    QDBusReply<QString> reply = sessioniface->call("access_current_desktop");
-//    return reply.value();
-//}
+QString SessionDispatcher::access_current_desktop_qt() {
+    QDBusReply<QString> reply = sessioniface->call("access_current_desktop");
+    return reply.value();
+}
 
 //QString SessionDispatcher::judge_desktop_is_unity_qt() {
 //    QDBusReply<QString> reply = sessioniface->call("judge_desktop_is_unity");
@@ -962,3 +1157,176 @@ int SessionDispatcher::get_thumbnail_cache_size_qt() {
 //    QDBusReply<QString> reply = sessioniface->call("judge_desktop_is_cinnamon");
 //    return reply.value();
 //}
+void SessionDispatcher::adjust_screen_gamma_qt(double gamma)
+{
+    sessioniface->call("adjust_screen_gamma", gamma);
+}
+
+double SessionDispatcher::get_screen_gamma_qt()
+{
+    QDBusReply<double> reply = sessioniface->call("get_screen_gamma");
+    return reply.value();
+}
+
+QStringList SessionDispatcher::get_idle_delay_list_qt()
+{
+    QDBusReply<QStringList> reply = sessioniface->call("get_idle_delay_list");
+    return reply.value();
+}
+
+QString SessionDispatcher::get_current_idle_delay_qt()
+{
+    QDBusReply<int> reply = sessioniface->call("get_current_idle_delay");
+    return QString::number(reply.value());
+}
+
+void SessionDispatcher::set_current_idle_delay_qt(int value)
+{
+    sessioniface->call("set_current_idle_delay", value);
+}
+
+bool SessionDispatcher::get_lock_enabled_qt()
+{
+    QDBusReply<bool> reply = sessioniface->call("get_lock_enabled");
+    return reply.value();
+}
+
+void SessionDispatcher::set_lock_enabled_qt(bool value)
+{
+    sessioniface->call("set_lock_enabled", value);
+}
+
+QStringList SessionDispatcher::get_lock_delay_list_qt()
+{
+    QDBusReply<QStringList> reply = sessioniface->call("get_lock_delay_list");
+    return reply.value();
+}
+
+QString SessionDispatcher::get_current_lock_delay_qt()
+{
+    QDBusReply<int> reply = sessioniface->call("get_current_lock_delay");
+    return QString::number(reply.value());
+}
+
+void SessionDispatcher::set_current_lock_delay_qt(int value)
+{
+    sessioniface->call("set_current_lock_delay", value);
+}
+
+QStringList SessionDispatcher::get_sleep_timeout_list_qt()
+{
+    QDBusReply<QStringList> reply = sessioniface->call("get_sleep_timeout_list");
+    return reply.value();
+}
+
+QString SessionDispatcher::get_current_critical_low_qt()
+{
+    QDBusReply<QString> reply = sessioniface->call("get_current_critical_low");
+    return reply.value();
+}
+
+void SessionDispatcher::set_current_critical_low_qt(QString value)
+{
+    sessioniface->call("set_current_critical_low", value);
+}
+
+
+QString SessionDispatcher::get_current_lid_battery_qt()
+{
+    QDBusReply<QString> reply = sessioniface->call("get_current_lid_battery");
+    return reply.value();
+}
+
+void SessionDispatcher::set_current_lid_battery_qt(QString value)
+{
+    sessioniface->call("set_current_lid_battery", value);
+}
+
+
+QString SessionDispatcher::get_current_lid_ac_qt()
+{
+    QDBusReply<QString> reply = sessioniface->call("get_current_lid_ac");
+    return reply.value();
+}
+
+void SessionDispatcher::set_current_lid_ac_qt(QString value)
+{
+    sessioniface->call("set_current_lid_ac", value);
+}
+
+
+QString SessionDispatcher::get_current_sleep_timeout_display_battery_qt()
+{
+    QDBusReply<int> reply = sessioniface->call("get_current_sleep_timeout_display_battery");
+    return QString::number(reply.value());
+}
+
+void SessionDispatcher::set_current_sleep_timeout_display_battery_qt(int value)
+{
+    sessioniface->call("set_current_sleep_timeout_display_battery", value);
+}
+
+QString SessionDispatcher::get_current_sleep_timeout_display_ac_qt()
+{
+    QDBusReply<int> reply = sessioniface->call("get_current_sleep_timeout_display_ac");
+    return QString::number(reply.value());
+}
+
+void SessionDispatcher::set_current_sleep_timeout_display_ac_qt(int value)
+{
+    sessioniface->call("set_current_sleep_timeout_display_ac", value);
+}
+
+
+QString SessionDispatcher::get_current_sleep_timeout_battery_qt()
+{
+    QDBusReply<int> reply = sessioniface->call("get_current_sleep_timeout_battery");
+    return QString::number(reply.value());
+}
+
+void SessionDispatcher::set_current_sleep_timeout_battery_qt(int value)
+{
+    sessioniface->call("set_current_sleep_timeout_battery", value);
+}
+
+QString SessionDispatcher::get_current_sleep_timeout_ac_qt()
+{
+    QDBusReply<int> reply = sessioniface->call("get_current_sleep_timeout_ac");
+    return QString::number(reply.value());
+}
+
+void SessionDispatcher::set_current_sleep_timeout_ac_qt(int value)
+{
+    sessioniface->call("set_current_sleep_timeout_ac", value);
+}
+
+// notify changes
+void SessionDispatcher::handler_notify_boolean(QString key, bool value)
+{
+//    if (key == "home-icon-visible")
+//    {
+//        qDebug() << "home-icon-visible->" << value;
+//    }
+//     qDebug() << key;
+//     qDebug() << value;
+    emit bool_value_notify(key, value);
+}
+
+void SessionDispatcher::handler_notify_int(QString key, int value)
+{
+    emit int_value_notify(key, value);
+}
+
+void SessionDispatcher::handler_notify_double(QString key, double value)
+{
+    emit double_value_notify(key, value);
+}
+
+void SessionDispatcher::handler_notify_string(QString key, QString value)
+{
+//    if (key == "gtk-theme")
+//    {
+//    }
+    emit string_value_notify(key, value);
+}
+
